//------------------------------------------------------------------------------
//	$Id: disqus-on-demand.js,v 1.3 2018/12/18 01:13:20 wolf Exp $
//------------------------------------------------------------------------------
//	Laedt einen Disqus-Diskussionsbereich nach Freigabe durch Besucher
//------------------------------------------------------------------------------
//	https://disqus.com/admin/install/platforms/universalcode/
//	https://help.disqus.com/developer/javascript-configuration-variables
//	https://help.disqus.com/troubleshooting/use-configuration-variables-
//				to-avoid-split-threads-and-missing-comments
//------------------------------------------------------------------------------

/*jsl:option explicit*/

'use strict';

function addListener (element, eventName, handler) {
	if (element.addEventListener) {
		element.addEventListener(eventName, handler, false);
	} else if (window.document.attachEvent) {
		element.attachEvent('on'+eventName, handler);
	} else {
		window.alert ('Neither addEventListener nor attachEvent defined.');
	}
}

var disqus_config = null;

addListener (window, 'load', function() {

	var container = document.getElementById('disqus');
	if (!container) return;

	//----------------------------------------------------------------------
	//	Haengt rekursiv child-Elemente an Element an
	//----------------------------------------------------------------------

	var ac = function (element, childs) {

		if (!childs) return;
		if (!(childs instanceof Array)) childs = [childs];

		while (childs.length) {

			var child = childs.shift();
			if (!child) continue;

			if (child instanceof Array) {

				childs=child.concat(childs);
				continue;
			}

			switch(typeof(child)) {

			case 'string':
			case 'number':
				element.appendChild(document.createTextNode(child));
				continue;
				break;
			default:
				element.appendChild(child);
				break;
			}
		}
	};

	//----------------------------------------------------------------------
	//	Erzeugt ein Element und haengt Child-Elemente an
	//----------------------------------------------------------------------

	var n = function (tagName, childs) {

		var element = document.createElement (tagName);
		ac(element, childs);
		return element;
	};

	//----------------------------------------------------------------------
	//	Erzeugt ein Element und haengt Attribute und Childs-Elemente an
	//----------------------------------------------------------------------

	var nx = function (tagName, attr, childs) {

		var element = document.createElement (tagName);

		for (var key in (attr||[])) {

			element.setAttribute(key, attr[key]);
		}

		ac(element, childs);
		return element;
	};

	//----------------------------------------------------------------------
	//	Lade Opengraph-Seitentitel
	//----------------------------------------------------------------------

	var getOpengraphTitle = function () {

		var elements = document.getElementsByTagName('meta');
		for (var i=0; i<elements.length; i++) {

			var element = elements[i];
			if (element.getAttribute('name') == 'og:title') {

				return element.getAttribute('content');
			}
		}

		return null;
	};

	//----------------------------------------------------------------------
	//	Erzeuge die disqus-Intro-Box
	//----------------------------------------------------------------------

	var init = function () {

		var header = container.getAttribute('data-header') ||
					'Leserkommentare:';

		//--------------------------------------------------------------
		//	Ablehnungs-Button
		//--------------------------------------------------------------

		var buttonNo = n('button', 'Nein danke!');

		buttonNo.onclick = function() {

			container.parentElement.removeChild(container);
		};

		//--------------------------------------------------------------
		//	Zustimmungs-Button
		//--------------------------------------------------------------

		var buttonOk = n('button', 'Disqus starten');

		buttonOk.onclick = function() {

			var shortname = container.getAttribute('data-shortname');

			//------------------------------------------------------
			//	Disqus Konfiguration: Identifier
			//------------------------------------------------------

			var identifier =
				container.getAttribute('data-identifier') ||
				container.getAttribute('data-path') ||
				null;

			//------------------------------------------------------
			//	Disqus Konfiguration: Title
			//------------------------------------------------------

			var title =
				container.getAttribute('data-title') ||
				getOpengraphTitle() ||
				null;

			//------------------------------------------------------
			//	Disqus Konfiguration: URL
			//------------------------------------------------------

			var url = container.getAttribute('data-url');

			if (!url && container.getAttribute('data-url-prefix')) {

				url = container.getAttribute('data-url-prefix') +
					(container.getAttribute('data-path') ||
						window.location.pathname);
			}

			if (!url && container.getAttribute('data-path')) {

				url = window.location.protocol +
					'//' + window.location.host +
					container.getAttribute('data-path');
			}

			url = url || null;

			//------------------------------------------------------
			//	Disqus Konfiguration: Category_Id
			//------------------------------------------------------

			var category_id =
				container.getAttribute('data-category_id') || null;

			//------------------------------------------------------
			//	Disqus Konfiguration: Script-Source
			//------------------------------------------------------

			var src = '//' + shortname + '.disqus.com/embed.js';

			//------------------------------------------------------
			//	Speichere Konfiguration
			//------------------------------------------------------

			disqus_config = function () {

				this.page.identifier = identifier;
				this.page.title = title;
				this.page.url = url;
				this.page.category_id = category_id;
			};

			//------------------------------------------------------
			//	Ueberpruefe auf Wunsch die Konfiguration
			//------------------------------------------------------

			if (parseInt(container.getAttribute('data-debug'))) {

				if (!confirm(
					'shortname: ' + shortname + '\n' +
					'identifier: ' + identifier + '\n' +
					'title: ' + title + '\n' +
					'url: ' + url + '\n' +
					'category_id: ' + category_id + '\n' +
					'script-src: ' + src + '\n\n' +
					'Disqus mit diesen Parametern starten?')) return;
			}

			//------------------------------------------------------
			//	Lade Skript von Disqus
			//------------------------------------------------------

			var newDiv = nx('container',
				{'id': 'disqus_thread'},
				'Disqus wird geladen \u2026');

			container.parentElement.insertBefore(n('hr'), container);
			container.parentElement.insertBefore(n('h2', header), container);
			container.parentElement.insertBefore(newDiv, container);
			container.parentElement.removeChild(container);

			var s = document.createElement('script');
			s.src = src;
			s.setAttribute('data-timestamp', +new Date());
			(document.head||document.body).appendChild(s);
		};

		//--------------------------------------------------------------
		//	Baue Infoseite
		//--------------------------------------------------------------

		ac(container, [
			n('hr'),
			n('h2', header),
			n('p', [
				'Die Kommentarfunktion wird von ',
				n('q', [
					nx('a', {
						'href': 'https://disqus.com/about/',
						'hreflang': 'en-US',
						'rel': 'external',
						'target': '_blank'
					}, 'Disqus, Inc.')
				]),
				' bereitgestellt. ',
				'Bei Nutzung werden Daten in die USA \xfcbertragen und auf Servern von Disqus gespeichert. ',
				'Lesen sie bitte die Wikipedia-Artikel zu ',
				nx('a', {
					'href': 'https://de.wikipedia.org/wiki/Disqus#Datenschutz',
					'rel': 'external',
					'target': '_blank'
				}, 'Disqus'),
				', ',
				nx('a', {
					'href': 'https://de.wikipedia.org/wiki/Datenschutz#Vereinigte_Staaten',
					'rel': 'external',
					'target': '_blank'
				}, 'Datenschutzrecht in den USA'),
				' und ',
				nx('a', {
					'href': 'https://de.wikipedia.org/wiki/Safe_Harbor',
					'rel': 'external',
					'target': '_blank'
				}, 'Safe Harbor'),
				' sowie die ',
				nx('a', {
					'href': 'https://help.disqus.com/customer/portal/articles/466259-privacy-policy',
					'hreflang': 'en-US',
					'rel': 'external',
					'target': '_blank'
				}, 'Privacy Policy von Disqus'),
				' (englisch). Nutzen sie die Kommentarfunktion ',
				n('b', 'nur dann'),
				', wenn sie den beschriebenen Umgang mit Ihren Daten ',
				n('b', 'akzeptieren'),
				'; bei Unklarheiten ',
				n('b', 'verzichten Sie bitte auf die Nutzung.'),
				' Danke.'
			]),
			n('p', [
				buttonOk, buttonNo
			])
		]);

		buttonOk.scrollIntoView({'behavior':'smooth'});
	};

	//----------------------------------------------------------------------
	//	Erzeuge Startbutton
	//----------------------------------------------------------------------

	var label = container.getAttribute('data-button-label') ||
			'Kommentarbereich anzeigen';

	var button = n('button', label);

	button.onclick = function() {

		container.removeChild(this);
		init();
	};

	container.appendChild (button);
});

//------------------------------------------------------------------------------
//	$Id: disqus-on-demand.js,v 1.3 2018/12/18 01:13:20 wolf Exp $
//------------------------------------------------------------------------------
